/*******************************************************
* input:	monthly city panel
* output:	figures and tables in $outfolder
* date:		1. September 2023
* authors:	Cannon Cloud, Johannes Kasinger, Simon Heß
* purpose: 	this file installs stata dependencies and executes 
*			sequentially all Stata analyses for the paper and appendix
*			For details, consult the readme.md
********************************************************/

clear all
set matsize 11000
set graphics off


// load dependencies
/* install if needed
foreach package in unique coefplot ppmlhdfe ivreghdfe ivreg2 erepost estout did_imputation twowayfeweights csdid drdid ranktest {
	cap noi ssc install `package'
}
net install ftools, from("https://raw.githubusercontent.com/sergiocorreia/ftools/master/src/") replace
net install reghdfe, from("https://raw.githubusercontent.com/sergiocorreia/reghdfe/master/src/") replace
net install ivreghdfe, from(https://raw.githubusercontent.com/sergiocorreia/ivreghdfe/master/src/) replace
net install  http://digital.cgdev.org/doc/stata/MO/Misc/grc1leg2
*/

// run stata code
do "2 - BJS event-study estimates.do"
do "3 - annualized DiD.do"
do "4 - OLS event-study plots.do"
do "5 - CS event-study plot.do"
do "6 - descriptives.do"
do "7 - city-level analyses.do"
do "8 - poisson and IV.do"
