library(haven)
library(modelsummary)
library(dplyr)
library(zoo)
city_level <- read_dta("data/monthly-panel.dta") |>
  mutate(month_intro = lubridate::ymd("1960-01-01") + months(month_intro)) |>
  filter(evertreated==1) |>
  group_by(city_id, population, month_intro, sh_bikable, carsper100, cmode_imp, country,   city) |>
  summarize(winter_accidents = sum(accidents_month_all*wtr_winter)/sum(wtr_winter)/mean(population)*10000,
            summer_accidents = sum(accidents_month_all*wtr_summer)/sum(wtr_summer)/mean(population)*10000,
            sh_bikable = mean(sh_bikable)*100,
            accidents = mean(accidents_month_all)/mean(population)*10000
          )
t1 <- modelsummary::datasummary(
  (`population` = as.integer(population)) +
  (`month of first scooter introduction`=as.yearmon(month_intro)) + 
    (`monthly accidents per 10k inhabitants`=accidents) +
    (`monthly accidents per 10k inhabitants (Nov-Feb) `=winter_accidents) +
    (`monthly accidents per 10k inhabitants (Mar-Oct) `=summer_accidents) +
    (`share of bike lanes in road network (%)`=sh_bikable) +
    (`cycling modal split (%)`=cmode_imp) +
    (`cars per 1k inhabitants`=carsper100)
  ~  N + Median + Min + Max,
  data = city_level)  
print(t1)
