/*******************************************************
* input:	monthly city panel
* output:	figures and tables in $outfolder
* date:		1. September 2023
* authors:	Cannon Cloud, Johannes Kasinger, Simon Heß
*******************************************************/



clear all
set scheme s2color, perm
use "data\monthly-panel.dta"
global outfolder "output"
set varabbrev off

do "ado/split_regs.ado" // a programm to split Borusyak estimation results into multiple columns


// Estimation with did_imputation of Borusyak et al. (2021)
did_imputation Y city_id month_stat month_intro if evertreated==1, pretrend(12) horiz(0/18) leaveout avgeffectsby(cohorts_half_year )
estimates store bjs // storing the estimates for later


/******************* With never-treated (fig 6) *********************/

//borusyak with nevertreated	
did_imputation Y city_id month_stat month_intro,  ///
	leaveout avgeffectsby(cohorts_quarters) ///
	 wtr(wtr_full wtr_summer wtr_winter wtr_19p) 

eststo borusyaknt
estadd ysumm //each weight-specification is save in a separate estimate for using them in the tables later

	cap mat drop eymeanc
	foreach var of varlist wtr_full wtr_summer wtr_winter wtr_19p { 
		sum accidents_month_all if evertreated & treated ==0 [iweight = `var']
		matrix eymeanc = nullmat(eymeanc), r(mean)
	}
	estadd matrix eymeanc=eymeanc
			sum accidents_month_all if treated ==0 
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd scalar N_clust=r(sum)
			split_regs, estimate(borusyaknt)



did_imputation Y city_id month_stat month_intro ,  ///
	horizons(0/18) 	pretrend(12)  ///
	avgeffectsby(cohorts_half_year) leaveout
	eststo bo18nt
	
	
	

//panel 3 (overall estimate)
coefplot borusyaknt, vertical keep(tau_wtr_full ) name(f1p3_nt, replace)  xtitle(" ") ylab("") xlab(1 "average") levels(95) ysc(off) fxsize(10) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	)  ///
title((3)) 
	
//panel 4 (summerestimate)
coefplot borusyaknt, vertical keep(tau_wtr_summer ) name(f1p4_nt, replace) xtitle(" ") ylab("") xlab(1 "non-winter") levels(95) ysc(off) fxsize(10) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	)  ///
title((4)) 
	
	
//panel 5 (winter estimate)
coefplot borusyaknt, vertical keep(tau_wtr_winter ) name(f1p5_nt, replace) xtitle(" ") ylab("") xlab(1 "winter") levels(95) ysc(off) fxsize(10) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	) ///
title((5)) 

	
//panel 2		
coefplot borusyaknt, vertical keep(tau_wtr_19p) name(f1p2_nt, replace) xtitle(" ") ylab("") xlab(1 ">18") levels(95) ysc(off)   fxsize(3) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	)  ///
title((2)) 
	
//panel 1 (did_plot)
event_plot bo18nt, default_look graph_opt(xtitle("Months relative to e-scooter introduction") ytitle("%-increase in accidents                        .") ///
	name(f1p1_nt, replace) title((1)) ///
	ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	) ///
	xscale(range(-12,18))   xl(-12(6)18)) ///
	alpha(0.05) lag_ci_opt(color(gray%15 gray%15)) lead_ci_opt(color(gray%15 gray%15)) ///
	 lag_opt(color(black)) lead_opt(color(black) msymbol(Oh))
	 

//combine panels and plot
grc1leg2 f1p1_nt f1p2_nt f1p3_nt f1p4_nt f1p5_nt, ycomm rows(1) holes(3 4 5) commonscheme imargin(medsmall) graphregion(color(white)) iscale(*1.3) legscale(3)


graph export "$outfolder\fig6.pdf", as(pdf) replace



did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
     wtr(	wtr_full wtr_first_12m wtr_summer wtr_winter wtr_no_covid /// 
			wtr_12_early wtr_12_late wtr_second_12m ///  
		) ///
	leaveout avgeffectsby(cohorts_quarters)
eststo borusyak




//add some summary stats to the estimate that are stored in `borusyak'
	cap mat drop eymeanc
	foreach var of varlist wtr_full wtr_full wtr_summer wtr_winter wtr_no_covid /// 
			wtr_12_early wtr_12_late wtr_second_12m {
		sum accidents_month_all if evertreated & treated ==0 [iweight = `var']
		matrix eymeanc = nullmat(eymeanc), r(mean)
	}
	estadd matrix eymeanc=eymeanc
	//estadd matrix ymeanc=ymeanc
	unique city_id if e(sample) & treated
	estadd scalar treated_cities=r(sum) 
	unique city_id if e(sample) 
	estadd scalar N_clust=r(sum)
	estadd ysumm
			
//each weight-specification is saved in a separate estimate for using them in the tables later
split_regs, estimate(borusyak)

/*********** BORUSYAK WITH TIME TRENDS **********************/

did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
     wtr(	wtr_full wtr_first_12m wtr_summer wtr_winter wtr_no_covid ///
		) ///
		unitcontrols(month_stat) ///
	leaveout avgeffectsby(cohorts_quarters)
eststo borutrnd


//add some summary stats to the estimate that are stored in `borusyak'
	cap mat drop eymeanc
	foreach var of varlist wtr_full wtr_full wtr_summer wtr_winter wtr_no_covid { 
		sum accidents_month_all if evertreated & treated ==0 [iweight = `var']
		matrix eymeanc = nullmat(eymeanc), r(mean)
	}
	estadd matrix eymeanc=eymeanc
	unique city_id if e(sample) & treated
	estadd scalar treated_cities=r(sum) 
	unique city_id if e(sample) 
	estadd scalar N_clust=r(sum)
	estadd ysumm
split_regs, estimate(borutrnd)



did_imputation percentage_slight_accidents city_id month_stat month_intro  if evertreated==1,  ///
     wtr(	wtr_full wtr_first_12m ) ///
	leaveout avgeffectsby(cohorts_quarters)
eststo borusy_r1
	cap mat drop ymeanc
	foreach var of varlist wtr_full wtr_full  { 
		sum percentage_slight_accidents if evertreated & treated ==0 [iweight = `var']
		matrix ymeanc = nullmat(ymeanc), r(mean)
	}
	estadd matrix ymeanc=ymeanc
	//estadd matrix ymeanc=ymeanc
	unique city_id if e(sample) & treated
	estadd scalar treated_cities=r(sum) 
	unique city_id if e(sample) 
	estadd scalar N_clust=r(sum)
	estadd ysumm
	
	
split_regs, estimate(borusy_r1)



/******************************
 *** Event plots			***
 ******************************/
 
 
/** borusyak **/

//create the did_plot based on as specification whith 18 horizons and 12 pre-periods
did_imputation Y city_id month_stat month_intro if evertreated==1,  ///
	horizons(0/18) 	pretrend(12)  ///
	avgeffectsby(cohorts_half_year) leaveout
	eststo bo18
did_imputation Y city_id month_stat month_intro if evertreated==1,  ///
	wtr(wtr_19p) ///
	avgeffectsby(cohorts_half_year) leaveout
	eststo bo19plus
	

	
	
// summer stuff
did_imputation Y city_id month_stat month_intro if evertreated==1,  ///
	horizons(0/15) 	pretrend(12)  ///
	avgeffectsby(cohorts_half_year) ///
	wtr(wtr_summer) 
	eststo bosummer15
did_imputation Y city_id month_stat month_intro if evertreated==1,  ///
	wtr(wtr_16p_sum) ///
	avgeffectsby(cohorts_half_year)
	eststo bo16plussummer
	
	
	
//panel 3 (overall estimate)
coefplot borusyak, vertical keep(tau_wtr_full ) name(f1p3, replace)  xtitle(" ") ylab("") xlab(1 "average") levels(95) ysc(off) fxsize(10) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	)  ///
title((3)) 
	
//panel 4 (summerestimate)
coefplot borusyak, vertical keep(tau_wtr_summer ) name(f1p4, replace) xtitle(" ") ylab("") xlab(1 "non-winter") levels(95) ysc(off) fxsize(10) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	)  ///
title((4)) 
	
	
//panel 5 (winter estimate)
coefplot borusyak, vertical keep(tau_wtr_winter ) name(f1p5, replace) xtitle(" ") ylab("") xlab(1 "winter") levels(95) ysc(off) fxsize(10) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	) ///
title((5)) 
	
	

	
//panel 2	
	
coefplot bo19plus, vertical keep() name(f1p2, replace) xtitle(" ") ylab("") xlab(1 ">18") levels(95) ysc(off)   fxsize(3) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	)  ///
title((2)) 
	
	
	
//panel 1 (did_plot)
event_plot bo18, default_look graph_opt(xtitle("Months relative to e-scooter introduction") ytitle("%-increase in accidents                        .") ///
	name(f1p1, replace) title((1)) ///
	ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	) ///
	xscale(range(-12,18))   xl(-12(6)18)) ///
	alpha(0.05) lag_ci_opt(color(gray%15 gray%15)) lead_ci_opt(color(gray%15 gray%15)) ///
	 lag_opt(color(black)) lead_opt(color(black) msymbol(Oh))
	 

//combine panels and plot
grc1leg2 f1p1 f1p2 f1p3 f1p4 f1p5, ycomm rows(1) holes(3 4 5) commonscheme imargin(medsmall) graphregion(color(white)) iscale(*1.3) legscale(3)



graph export "$outfolder\fig2.pdf", as(pdf) replace





//create the did_plot based on as specification whith 18 horizons and 12 pre-periods
did_imputation percentage_slight_accidents city_id month_stat month_intro if evertreated==1,  ///
	horizons(0/18) 	pretrend(12)  ///
	avgeffectsby(cohorts_half_year) leaveout
	eststo r1bo18
did_imputation percentage_slight_accidents city_id month_stat month_intro if evertreated==1,  ///
	wtr(wtr_19p) ///
	avgeffectsby(cohorts_half_year) leaveout
	eststo r1bo19plus
	
//panel 3 (overall estimate)
coefplot borusy_r1, vertical keep(tau_wtr_full ) name(r1b, replace) xtitle("month-city") ylab(-10(2)10) xlab(1 "Average") levels(95) ysc(off) fxsize(20) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) 
	
//panel 2	
	
coefplot r1bo19plus, vertical keep() name(r1a24plus, replace) xtitle(" ") ylab("") xlab(1 ">18") levels(95) ysc(off)   fxsize(3) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(-10(2)10)
	
	
//panel 1 (did_plot)
event_plot r1bo18, default_look graph_opt(xtitle("Months relative to e-scooter introduction") ytitle("%-point change in share of accidents with slight injury") ///
	name(r1a, replace) ///
	ylab(-10(2)10) 	xscale(range(-12,18))   xl(-12(6)18)) ///
	alpha(0.05) lag_ci_opt(color(gray%15 gray%15)) lead_ci_opt(color(gray%15 gray%15)) ///
	 lag_opt(color(black)) lead_opt(color(black) msymbol(Oh))
//combine panels and plot
grc1leg2 r1a r1a24plus r1b, ycomm rows(1) holes(3 4 5) commonscheme imargin(medsmall) graphregion(color(white)) iscale(*1.3) legscale(3)


graph export "$outfolder\fig10.pdf", as(pdf) replace


/**********************************
 *** Event plot summer			***
 **********************************/

//panel 2 (overall estimate)
coefplot borusyak, vertical keep(tau_wtr_summer ) name(b16, replace) xtitle("month-city") ylab("") xlab(1 "Average") levels(95) ysc(off) fxsize(20) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0" `=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	`=ln((30/100)+1)' "30"	) 
	
coefplot bo16plussummer, vertical keep() name(a16plus, replace) xtitle(" ") ylab("") xlab(1 ">15") levels(95) ysc(off)   fxsize(3) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0" `=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	`=ln((30/100)+1)' "30"	) 

	
	
//panel 1 (did_plot)
event_plot bosummer15, default_look graph_opt(xtitle("Months relative to e-scooter introduction") ytitle("%-increase in accidents                        .") ///
	name(a15, replace) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0" `=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	`=ln((30/100)+1)' "30"	)  ///
	xscale(range(-12,15))   xl(-12(6)15)) ///
	alpha(0.05) lag_ci_opt(color(gray%15 gray%15)) lead_ci_opt(color(gray%15 gray%15)) ///
	 lag_opt(color(black)) lead_opt(color(black) msymbol(Oh))
//combine panels and plot
grc1leg2 a15 a16plus b16, ycomm rows(1) holes(3 4 5) commonscheme imargin(medsmall) graphregion(color(white)) iscale(*1.3) legscale(3)

graph export "$outfolder\fig8.pdf", as(pdf) replace

 
/*********************************
 *** Event plots (12m placebo) ***
 *********************************/

gen month_introp12 = month_intro-12
gen month_since_introp12 = month_stat-month_introp12
gen wtr_12_mop12 = month_since_introp12 <12 & month_since_introp12 >=0
local subsample_p12 evertreated==1 & month_stat <=737-12
did_imputation Y city_id month_stat month_introp12  if `subsample_p12' ,  ///
	wtr(wtr_full wtr_12_mop12 wtr_no_covid wtr_summer wtr_winter) autosample ///
	avgeffectsby(cohorts_half_year) leaveout

eststo borus12
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd scalar N_clust=r(sum)
			estadd ysumm
coefplot borus12, vertical keep(tau_wtr_12_mop12) name(b12, replace) xtitle("placebo post months") ylab("") xlab(1 "Average of first 12") levels(95) ysc(off) fxsize(20) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0" `=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	`=ln((30/100)+1)' "30"	) 


did_imputation Y city_id month_stat month_introp12 if `subsample_p12',  ///
	horizons(0/11) 	pretrend(12)  autosample ///
	avgeffectsby(cohorts_half_year) leaveout
	eststo b12o15

event_plot b12o15, default_look graph_opt(xtitle("Months relative to e-scooter introduction -12") ytitle("%-increase in accidents") ///
	name(a12, replace)  ///
	ylab(`=ln((-10/100)+1)' "-10"	///
	`=ln((0/100)+1)' "0"	///
	`=ln((10/100)+1)' "10"	///
	`=ln((20/100)+1)' "20"	///
	) ) ///
	alpha(0.05) lag_ci_opt(color(gray%15 gray%15)) lead_ci_opt(color(gray%15 gray%15)) ///
	 lag_opt(color(black)) lead_opt(color(black) msymbol(Oh))
grc1leg2 a12 b12, ycomm rows(1)  commonscheme imargin(medlarge) graphregion(color(white))  xsize(6) ysize(3) iscale(*1.5) legscale(5)

graph export "$outfolder\fig9a.pdf", as(pdf) replace



/*********************************
 *** Event plots (24m placebo) ***
 *********************************/

gen month_introp24 = month_intro-24

gen month_since_introp24 = month_stat-month_introp24
gen wtr_12_mop24 = month_since_introp24 <12 & month_since_introp24 >=0


local subsample_p24 evertreated==1 & month_stat <=737-24
did_imputation Y city_id month_stat month_introp24  if `subsample_p24',  ///
    wtr(wtr_full wtr_12_mop24 wtr_no_covid wtr_summer wtr_winter) autosample ///
	avgeffectsby(cohorts_half_year) leaveout 
eststo borus24
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd scalar N_clust=r(sum)
			estadd ysumm
coefplot borus24, vertical keep(tau_wtr_12_mop24) name(b24, replace) xtitle("placebo post months") ylab("") xlab(1 "Average first 12") levels(95) ysc(off) fxsize(20) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0" `=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	`=ln((30/100)+1)' "30"	) 


did_imputation Y city_id month_stat month_introp24 if `subsample_p24',  ///
	horizons(0/11) 	pretrend(12)  autosample ///
	avgeffectsby(cohorts_half_year) leaveout
	eststo b24o15
event_plot b24o15, default_look graph_opt(xtitle("Months relative to e-scooter introduction -24") ytitle("%-increase in accidents") ///
	name(a24, replace)  ///
	ylab(`=ln((-10/100)+1)' "-10"	///
	`=ln((0/100)+1)' "0"	///
	`=ln((10/100)+1)' "10"	///
	`=ln((20/100)+1)' "20"	///
	) ) ///
	alpha(0.05) lag_ci_opt(color(gray%15 gray%15)) lead_ci_opt(color(gray%15 gray%15)) ///
	 lag_opt(color(black)) lead_opt(color(black) msymbol(Oh))
grc1leg2 a24 b24, ycomm rows(1)  commonscheme imargin(medlarge) graphregion(color(white)) xsize(6) ysize(3) iscale(*1.5) legscale(5)

graph export "$outfolder\fig9b.pdf", as(pdf) replace
// end placebo



	
 


//borusyak with nevertreated	with city specific trends
did_imputation Y city_id month_stat month_intro,  ///
	leaveout avgeffectsby(cohorts_quarters) 		unitcontrols(month_stat) 
eststo borutrndnt
			mat Nt = e(Nt)
			sum accidents_month_all if treated ==0 
			estadd scalar eymeanc = r(mean)
			estadd scalar N_t = Nt[1,1]
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd scalar N_clust=r(sum)
			estadd ysumm

//borusyak with nevertreated	percentage_slight_accidents
did_imputation percentage_slight_accidents city_id month_stat month_intro,  ///
	leaveout avgeffectsby(cohorts_quarters)
eststo r1borusyaknt
			mat Nt = e(Nt)
			sum percentage_slight_accidents if treated ==0 
			estadd scalar ymeanc = r(mean)
			estadd scalar N_t = Nt[1,1]
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd scalar N_clust=r(sum)
			estadd ysumm

			
			
			
/*heterogeneity*/

foreach var of varlist sh_bikable carsper100 cmode_imp {
 //samplesplit:
 tempvar `var'_
 gen ``var'_' = `var' if opc & evertreated==1
 bys country: egen median_`var' = median(``var'_')
 
 gen wtr_`var'_high = `var'>median_`var' if !missing(`var') 
 sum wtr_`var'_high if treated
 replace wtr_`var'_high  = wtr_`var'_high / r(sum)

 gen wtr_`var'_low = !wtr_`var'_high if !missing(`var') 
 sum wtr_`var'_low  if treated
 replace wtr_`var'_low = wtr_`var'_low / r(sum)
 
 gen wtr_`var'_hl = wtr_`var'_high - wtr_`var'_low
 did_imputation Y city_id month_stat month_intro    if evertreated==1 ,  ///
    wtr(wtr_`var'_high  wtr_`var'_low wtr_`var'_hl) ///
	sum fe(city_id month_stat#wtr_`var'_high) ///
	leaveout avgeffectsby(cohorts_half_year)
	eststo borh_`var'
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd scalar N_clust=r(sum)		
			estadd ysumm
			lincom tau_wtr_`var'_hl
			estadd scalar p_diff=r(p)		
}
 
	
/* to control for invariant city char by period (by referee request) */

cap drop x_*
foreach var of varlist  sh_bikable carsper100 cmode_imp lp {
	forvalues y=2016/2021 {
		gen x_`var'_`y' = `var' * (year==`y')
		gen x_`var'_demeaned_`y' = `var'_demeaned * (year==`y')
		
		
	}
	
}


did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
     wtr(	wtr_full wtr_first_12m wtr_summer   ) ///
		fe(city_id month_stat) ///
		controls(x_sh_bikable_demeaned_2*) tol(`=10^(-6)') maxit(1000)  ///
	leaveout avgeffectsby(cohorts_quarters) 
	eststo bor_con1
	 
did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
     wtr(	wtr_full wtr_first_12m wtr_summer   ) ///
		fe(city_id month_stat) ///
		controls(x_carsper100_demeaned_2*) tol(`=10^(-6)') maxit(1000) ///
	leaveout avgeffectsby(cohorts_quarters) 
	eststo bor_con2
	

did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
     wtr(	wtr_full wtr_first_12m wtr_summer   ) ///
		fe(city_id month_stat) ///
		controls(x_cmode_imp_demeaned_2*) tol(`=10^(-6)') maxit(1000) ///
	leaveout avgeffectsby(cohorts_quarters) 
	eststo bor_con3
	
did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
     wtr(	wtr_full wtr_first_12m wtr_summer   ) ///
		fe(city_id month_stat) ///
		controls(x_lp_demeaned_2*)   tol(`=10^(-6)') maxit(1000) ///
	leaveout avgeffectsby(cohorts_quarters) 
	eststo bor_con5
	

did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
     wtr(	wtr_full wtr_first_12m wtr_summer   ) ///
		fe(city_id month_stat) ///
		controls(x_lp_demeaned_2* x_cmode_imp_demeaned_2* x_carsper100_demeaned_2* x_sh_bikable_demeaned_2*)     ///
	leaveout avgeffectsby(cohorts_quarters) 
 	eststo bor_con6
	
	

// panel 3
did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
		horizons(0/18) 	pretrend(12)  ///
		fe(city_id month_stat) ///
		controls(x_lp_demeaned_2* x_cmode_imp_demeaned_2* x_carsper100_demeaned_2* x_sh_bikable_demeaned_2*)   tol(`=10^(-6)') maxit(1000)  ///
	leaveout avgeffectsby(cohorts_half_year) 
 	eststo bor_con_plot
	
// panel 2
did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
		wtr(wtr_19p) ///
		fe(city_id month_stat) ///
		controls( x_lp_demeaned_2* x_cmode_imp_demeaned_2* x_carsper100_demeaned_2* x_sh_bikable_demeaned_2*)   tol(`=10^(-6)') maxit(1000)  ///
	leaveout avgeffectsby(cohorts_half_year) 
 	eststo borcon_plot19plus
	
coefplot borcon_plot19plus, vertical keep(tau) name(borcon2, replace) xtitle(" ") ylab("") xlab(1 ">18") levels(95) ysc(off) fxsize(3) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0" `=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	`=ln((30/100)+1)' "30"	) 

	
//panel 3 (overall estimate)
coefplot bor_con6, vertical keep(tau_wtr_full) name(borcon3, replace)  xtitle(" ") ylab("") xlab(1 "average") levels(95) ysc(off) fxsize(10) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	) 
	
	
	
event_plot bor_con_plot, default_look graph_opt(xtitle("Months relative to e-scooter introduction") ytitle("%-increase in accidents") ///
	name(borcon1, replace)  ///
	ylab(`=ln((-10/100)+1)' "-10" `=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	) ) ///
	alpha(0.05) lag_ci_opt(color(gray%15 gray%15)) lead_ci_opt(color(gray%15 gray%15)) lag_opt(color(black)) lead_opt(color(black) msymbol(Oh)) 
grc1leg2 borcon1 borcon2 borcon3, ycomm rows(1)  commonscheme imargin(medlarge) graphregion(color(white))  iscale(*1.5) legscale(5) 

graph export "$outfolder\fig7.pdf", as(pdf) replace
	

//to create nicer outputs, we need to create and label a few vars:
gen borusyak =.
label var borusyak  "\%-increase in accidents"
gen tau_wtr_full =.
label var tau_wtr_full  "\%-increase in accidents"

gen  tau_wtr_first_12m=.
label var tau_wtr_first_12m  "\%-increase in accidents during the first 12 months"
gen tau_wtr_summer      =.
label var  tau_wtr_summer        "\%-increase in accidents during summer months"

gen tau_wtr_carsper100_high =.
label var tau_wtr_carsper100_high  "\%-increase in accidents for above-median cities"
gen tau_wtr_carsper100_low =. 
label var tau_wtr_carsper100_low  "\%-increase in accidents for below-median cities"


label var change_accidents_12y "\(\Delta_{12}\log(\sum_{k=1}^{12}\textrm{accidents}_{i\{t-k\}})\)"
label var change_accidents_12m "\(\Delta_{12}\log \textrm{accidents}_{it}\)"
	
gen borusy_r1 = .
label var borusy_r1  "\%-point change"

esttab ///
		borusy_r1_tau_wtr_full r1borusyaknt borusy_r1_tau_wtr_first_12m  ///
		using "$outfolder\tab14.tex", replace nonotes booktabs se starlevels(* 0.1 ** 0.05 *** 0.01) ///
		rename(tau borusy_r1 ) ///
		lab ml("Main sample"  "\shortstack{Incl. never-\\treated cities}" "\shortstack{First 12\\months}" ) ///
		stats(ymeanc  treated_cities  N_t N N_clust, label("Pre-treat. mean"  "%treated cities" "Treated observations" "Total observations" "Cities" ) fmt(1 0 0 0 0)  layout("\phantom{space}\clap{@\%}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" )) ///
		 cells(b(fmt(1)) se(par(( ))) ci(par([ ", " ]))) collabels(,none)
		 
		 
esttab ///
		borutrnd_tau_wtr_full borutrndnt borutrnd_tau_wtr_first_12m  ///
		using "$outfolder\tab12.tex", replace nonotes booktabs se starlevels(* 0.1 ** 0.05 *** 0.01) ///
		rename(borutrnd borusyak tau borusyak ) ///
		lab transform(100*(exp(@)-1) 100*exp(@)) ///
		ml("Main sample"  "\shortstack{Incl. never-\\treated cities}" "\shortstack{First 12\\months}" "\shortstack{Non-winter}"  "\shortstack{Winter}"  "\shortstack{Excluding\\COVID}"  ""  "\shortstack{Incl. never-\\treated cities}") ///
		stats(ymeanc eymeanc  treated_cities  N_t N N_clust, label("%mean pre-treatment log(accidents)" "Mean pre-treatment accidents" "%treated cities" "Treated observations" "Total observations" "Cities" ) fmt(2 1 0 0 0 0)  layout("\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}")) ///
		 se(1) b(1)
		
		
		
		
esttab ///
		borusyak_tau_wtr_full borusyaknt_tau_wtr_full borusyak_tau_wtr_first_12m borusyak_tau_wtr_summer borusyak_tau_wtr_winter borusyak_tau_wtr_no_covid ///
		using "$outfolder\tab10.tex", replace nonotes booktabs se starlevels(* 0.1 ** 0.05 *** 0.01) ///
		rename(tau borusyak borusyaknt borusyak) ///
		lab transform(100*(exp(@)-1) 100*exp(@)) ///
		ml("Main sample"  "\shortstack{Incl. never-\\treated cities}" "\shortstack{First 12\\months}" "\shortstack{Non-winter}"  "\shortstack{Winter}"  "\shortstack{Excluding\\COVID}" ) ///
		mgroup("\shortstack{Monthly event-study estimate\\~}", pattern(1 0 0 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(})  erepeat(\cmidrule(lr){@span}) span) ///
		stats(ymeanc eymeanc  treated_cities  N_t N N_clust, label("%mean pre-treatment log(accidents)" "Mean pre-treatment accidents" "%treated cities" "Treated observations" "Total observations" "Cities" ) fmt(2 1 0 0 0 0)  layout("\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}")) ///
		se(1) b(1)
	
esttab ///
		borusyak_tau_wtr_first_12m borusyak_tau_wtr_second_12m borusyak_tau_wtr_12_early borusyak_tau_wtr_12_late ///
		using "$outfolder\tab15.tex", replace nonotes booktabs se starlevels(* 0.1 ** 0.05 *** 0.01) ///
		lab transform(100*(exp(@)-1) 100*exp(@)) ///
		ml("\shortstack{Months 0--11}"  "\shortstack{Months 12--23}" "\shortstack{Early adopters}" "\shortstack{Late adopters}" ) ///
		stats(treated_cities N_clust N_t N , label("%Treated cities" "Cities" "%Treated observations" "Total observations") fmt(0 0 0)) ///
		se(1) b(1)

		
esttab ///
		bor_con? ///
		using "$outfolder\tab13.tex", replace nonotes booktabs se starlevels(* 0.1 ** 0.05 *** 0.01) ///
		lab transform(100*(exp(@)-1) 100*exp(@)) nomtitles indicate("share of bike lanes \(\times\) year FX=x_sh_bikable_*"  ///
		"cars per capita \(\times\) year FX=x_carsper100*" ///
		"cycling modal share \(\times\) year FX=x_cmode_imp*" ///
		"log(population)  \(\times\) year FX =x_lp*" ///
		,		label("\(\checkmark\)" "~")) ///
		se(1) b(1)
	
		
	
		
esttab borh_*   ///
		using "$outfolder\tab2.tex", replace nonotes booktabs se starlevels(* 0.1 ** 0.05 *** 0.01) ///
		lab transform(100*(exp(@)-1) 100*exp(@)) ///
		nodepv nomtitles mgroup("\shortstack{Share of\\bike lanes}" "\shortstack{Cars per\\capita}" "\shortstack{Cycling\\modal share}", pattern(1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(})  erepeat(\cmidrule(lr){@span}) span) ///
		stats(p_diff   N_clust N , label("\(p\)-value \(H_o\): coefficients identical"   "Cities" "Observations") fmt(3 0 0 0 0)) ///
		se(1) b(1) sub(\_ _)  ///
		rename(	tau_wtr_cmode_imp_high 	tau_wtr_carsper100_high tau_wtr_sh_bikable_high	tau_wtr_carsper100_high	tau_wtr_PPS_pc_high	tau_wtr_carsper100_high  ///
				tau_wtr_cmode_imp_low 	tau_wtr_carsper100_low 	tau_wtr_sh_bikable_low 	tau_wtr_carsper100_low	tau_wtr_PPS_pc_low 	tau_wtr_carsper100_low) ///
		drop(tau_wtr_cmode_imp_hl	tau_wtr_carsper100_hl 	tau_wtr_sh_bikable_hl )
