/*******************************************************
* input:	monthly city panel
* output:	figures and tables in $outfolder
* date:		1. September 2023
* authors:	Cannon Cloud, Johannes Kasinger, Simon Heß
*******************************************************/


clear all
global outfolder "output"
set varabbrev off
set graphics off

use "data\monthly-panel.dta"

/******************************************/
/***     COLLAPSE INTO AN ANNUAL PANEL ****/
/******************************************/

collapse ///
		(sum) acci_all_yearly = accidents_month_all ///
		(count) ex_acci_all_yearly = accidents_month_all ///
		(mean) opc ///
		(min) first_month=month_stat ///
		, by(city_id city country evertreated year sh_bikable   		carsper100 		 cmode_imp	   logincome lp population month_intro*)

replace acci_all_yearly = . if ex_acci_all_yearly< 12
gen log_all_yearly=log(acci_all_yearly)

gen treat_full = month_intro <= first_month & !missing(month_intro)
xtset city_id  year


gen didsample = (month_intro >=708 & month_intro <=719) | 	/// treatment group
				(month_intro >=726 & month_intro <=.)		// control group
	
	
	
eststo fyearly: reghdfe log_all_yearly treat_full if /// 
		inlist(year,2018,2020) & didsample & evertreated==1 , a(city_id year) cluster(city_id)
		sum treat_full if e(sample) 
		estadd scalar treated_cities=r(sum)
		estadd scalar N_t=r(sum)			
		sum acci_all_yearly if e(sample) & year == 2018
		estadd scalar eymeanc=r(mean)		
		estadd ysumm
eststo fyearlynever: reghdfe log_all_yearly treat_full if /// 
		inlist(year,2018,2020) & didsample , a(city_id year) cluster(city_id)
		sum treat_full if e(sample) 
		estadd scalar treated_cities=r(sum)
		estadd scalar N_t=r(sum)			
		sum acci_all_yearly if e(sample) & year == 2018
		estadd scalar eymeanc=r(mean)		
		estadd ysumm
	
//TE heterogeneity in the DID model
label define lowhigh 0 "Below-median" 1 "Above-median", replace
foreach var of varlist sh_bikable   		carsper100 		 cmode_imp	   {
	tempvar `var'_
	gen ``var'_' = `var' if opc & evertreated==1
	bys country: egen cmed_`var' = median(``var'_')
	gen  `var'_high = (`var' > cmed_`var') if !missing(`var')
	label values `var'_high lowhigh
	eststo didhet_`var': reghdfe log_all_yearly c.treat_full#i.`var'_high i.year#c.`var'_high  if ///
		inlist(year,2018,2020) & didsample & evertreated==1 , a(city_id year) cluster(city_id)
	lincom 0.`var'_high#c.treat_full - 1.`var'_high#c.treat_full
	estadd scalar diff_b=r(estimate)
	estadd scalar diff_se=r(se)
	estadd scalar diff_p=r(p)
	sum treat_full if e(sample) 
	estadd scalar treated_cities=r(sum)
	estadd ysumm
}



label var treat_full  "\%-increase in accidents"



		
esttab ///
		fyearly fyearlynever /// 
		using "$outfolder\tab3.tex", replace nonotes booktabs se starlevels(* 0.1 ** 0.05 *** 0.01) ///
		lab transform(100*(exp(@)-1) 100*exp(@)) ///
		ml(""  "\shortstack{Incl. never-\\treated cities}") ///
		mgroup("\shortstack{2018 vs 2020\\difference-in-differences}" , pattern(1 0 ) prefix(\multicolumn{@span}{c}{) suffix(})  erepeat(\cmidrule(lr){@span}) span) ///
		stats(ymeanc eymeanc  treated_cities  N_t N N_clust, label("%mean pre-treatment log(accidents)" "Mean pre-treatment accidents" "%treated cities" "Treated observations" "Total observations" "Cities" ) fmt(2 1 0 0 0 0)  layout("\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}" "\phantom{space}\clap{@}\phantom{space}")) ///
		drop("_cons")   se(1) b(1)




	
esttab didhet_*  ///
		using "$outfolder\tab16.tex", replace nonotes booktabs se starlevels(* 0.1 ** 0.05 *** 0.01) ///
		rename(0.cmode_imp_high#c.treat_full 0.sh_bikable_high#c.treat_full 0.carsper100_high#c.treat_full 0.sh_bikable_high#c.treat_full 0.PPS_pc_high#c.treat_full 0.sh_bikable_high#c.treat_full ///
			   1.cmode_imp_high#c.treat_full 1.sh_bikable_high#c.treat_full 1.carsper100_high#c.treat_full 1.sh_bikable_high#c.treat_full 1.PPS_pc_high#c.treat_full 1.sh_bikable_high#c.treat_full ///
		) ///
		nodepv nomtitles lab transform(100*(exp(@)-1) 100*exp(@)) ///
		mgroup("\shortstack{Share of\\bike lanes}" "\shortstack{Cars per\\capita}" "\shortstack{Cycling\\modal share}", pattern(1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(})  erepeat(\cmidrule(lr){@span}) span) ///
		stats(diff_p treated_cities N_clust N , label("\(p\)-value \(H_o\): coefficients identical" "%Treated cities" "Cities" "Observations") fmt(2 0 0 0 0)) ///
		drop("_cons" 20*#*_high)   se(1) b(1) interact(":\\") sub(\_ _)  









