/*******************************************************
* input:	monthly city panel
* output:	figures and tables in $outfolder
* date:		1. September 2023
* authors:	Cannon Cloud, Johannes Kasinger, Simon Heß
*******************************************************/



clear all
set scheme s2color, perm

global outfolder "output"
set varabbrev off
set graphics on

use "data\monthly-panel.dta"

forvalues l = 0/100 {
	gen L`l'event = month_since_intro==`l'
}

cap drop O*event
forvalues l = 2/70 {
	gen O`l'event = month_since_intro==-`l' // normalize K=-1 to zero
}
// TWFE OLS estimation 

reghdfe Y L*event  O*event  if evertreated==1 , abs(city_id month_stat) cluster(city_id)
estimates store ols // saving the estimates for later

reghdfe Y L*event  O*event  if evertreated==1 & month_stat >= 675, abs(city_id month_stat) cluster(city_id)
estimates store ols2016m4  // saving the estimates for later



// compute implied weights of OLS ATT
reghdfe Y treated if evertreated==1,a(city_id month_stat) cluster(city_id)
twowayfeweights Y city_id month_stat treated if evertreated==1, type(feTR)



	
//panel 1 (did_plot)
event_plot ols, default_look ///
	stub_lead( O#event) trimlead(12) ///
	stub_lag( L#event) trimlag(18) ///
	graph_opt(xtitle("Months relative to e-scooter introduction") ytitle("%-increase in accidents                        .") ///
	name(a, replace) ///
	ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	) ///
	xscale(range(-12,18))   xl(-12(6)18)) ///
	alpha(0.05) lag_ci_opt(color(gray%15 gray%15)) lead_ci_opt(color(gray%15 gray%15)) ///
	 lag_opt(color(black)) lead_opt(color(black) msymbol(Oh))
//combine panels and plot

graph export "$outfolder\fig4b.pdf", as(pdf) replace

//panel 1 (did_plot)
event_plot ols2016m4, default_look ///
	stub_lead( O#event) trimlead(12) ///
	stub_lag( L#event) trimlag(18) ///
	graph_opt(xtitle("Months relative to e-scooter introduction") ytitle("%-increase in accidents                        .") ///
	name(a, replace) ///
	ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"	) ///
	xscale(range(-12,18))   xl(-12(6)18)) ///
	alpha(0.05) lag_ci_opt(color(gray%15 gray%15)) lead_ci_opt(color(gray%15 gray%15)) ///
	 lag_opt(color(black)) lead_opt(color(black) msymbol(Oh))
//combine panels and plot

graph export "$outfolder\fig4a.pdf", as(pdf) replace

