/*******************************************************
* input:	monthly city panel
* output:	figures and tables in $outfolder
* date:		1. September 2023
* authors:	Cannon Cloud, Johannes Kasinger, Simon Heß
*******************************************************/



clear all
set scheme s2color, perm

//ssc install unique  coefplot ppmlhdfe ivreghdfe ivreg2 ranktest erepost
//ssc install csdid
global outfolder "output"
set varabbrev off
set graphics off

use "data\monthly-panel.dta"

gen gvar = cond(month_intro==., 0, month_intro) // group variable as required for the csdid command
csdid Y if evertreated==1, ivar(city_id) time(month_stat) gvar(gvar) notyet saverif(csrif ) replace
estat event, estore(cs) // this produces and stores the estimates at the same time
estat cevent, window(19 111) estore(cs_18p2) // this produces and stores the estimates at the same time
estat simple, estore(cs_ATT) // this produces and stores the estimates at the same time



/** CS **/
	
coefplot cs_ATT, vertical keep(ATT ) name(b, replace) xtitle("month-city") ylab("") xlab(1 "Average") levels(95) ysc(off) fxsize(20) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"		`=ln((30/100)+1)' "30"	) 
	


	
	
coefplot cs_18p2, vertical  name(a24plus, replace) xtitle(" ") ylab("") xlab(1 ">18") levels(95) ysc(off)   fxsize(3) yline(0, lc(gray)) graphregion(color(white)) mc(black) ciopts(lc(black) ) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"		`=ln((30/100)+1)' "30"	) 
	
	
	
event_plot cs, default_look ///
	stub_lead(Tm#) trimlag(18) ///
	stub_lag(Tp#) trimlead(12) ///
	graph_opt(xtitle("Months relative to e-scooter introduction") ytitle("%-increase in accidents                        .") ///
	name(a, replace) ///
ylab(`=ln((-10/100)+1)' "-10"	`=ln((0/100)+1)' "0"	`=ln((10/100)+1)' "10"	`=ln((20/100)+1)' "20"		`=ln((30/100)+1)' "30"	)  ///
	xscale(range(-12,18))   xl(-12(6)18)) ///
	alpha(0.05) lag_ci_opt(color(gray%15 gray%15)) lead_ci_opt(color(gray%15 gray%15)) ///
	 lag_opt(color(black)) lead_opt(color(black) msymbol(Oh))
//combine panels and plot
grc1leg2 a a24plus b, ycomm rows(1) holes(3 4 5) commonscheme imargin(medsmall) graphregion(color(white)) iscale(*1.3) legscale(3)


graph export "$outfolder\fig5.pdf", as(pdf) replace



rm csrif.dta
