/*******************************************************
* input:	monthly city panel
* output:	figures and tables in $outfolder
* date:		1. September 2023
* authors:	Cannon Cloud, Johannes Kasinger, Simon Heß
*******************************************************/




clear all
global outfolder "output"
set varabbrev off
set graphics off

use "data\monthly-panel.dta"




/*** fig 11**/
//create moving average
sort city_id month_stat
bys city_id : gen ma5 = 1/3*(Y+Y[_n-1]+Y[_n+1])
twoway	(line ma5 month_stat if !treated & evertreated	,				 connect(L) lwidth(vthin) color(navy%50)) ///
		(line ma5 month_stat if treated					, lpattern(dash) connect(L) lwidth(vthin) color(navy%50)) ///
		, xtitle(Month) ytitle(3-months MA of log(accidents)) graphregion(color(white))  legend(label(1 "Pre-launch") label(2 "Post-launch"))
graph export "$outfolder\fig11.pdf", as(pdf) replace

gen year_intro = year(dofm(month_intro))
replace year_intro = 9999 if year_intro == .

// looking at 2017-2018, see if those that launched in 2019 (and 2020?) different from later treated
label define yl 9999 "never-treated" 2020 "treated 2020" 2021 "treated 2021", replace
label values year_intro yl
label var year_intro "launch"
label var month_stat "month"

qui eststo nevertreated_bad_choice1: reghdfe Y c.month_stat#i2020.year_intro if inrange(year,2017,2018) & inlist(year_intro,2019,2020), a(month_stat city_id) cluster(city_id)
estadd local sampleyears "2017-2018"
estadd local samplecities "2019/2020"

qui eststo nevertreated_bad_choice2: reghdfe Y c.month_stat#i2021.year_intro if inrange(year,2017,2018) & inlist(year_intro,2019,2021), a(month_stat city_id) cluster(city_id)
estadd local sampleyears "2017-2018"
estadd local samplecities "2019/2021"

qui eststo nevertreated_bad_choice3: reghdfe Y c.month_stat#i9999.year_intro if inrange(year,2017,2018) & inlist(year_intro,2019,9999), a(month_stat city_id) cluster(city_id)
estadd local sampleyears "2017-2018"
estadd local samplecities " 2019/never"

qui eststo nevertreated_bad_choice4: reghdfe Y c.month_stat#i(2020 2021 9999).year_intro if inrange(year,2017,2018) & inlist(year_intro,2019,2020,2021,9999), a(month_stat city_id) cluster(city_id)
estadd local sampleyears "2017-2018"
estadd local samplecities "2019-2021/never"

estadd ysumm: nevertreated_bad_choice? 




//table 9
eststo splag1: reghdfe new_launch nb_scoots_2_month all_scoots_2_month if evertreated & year>=2018,a(city_id month_stat ) cluster(city_id)
eststo splag2: reghdfe new_launch nb_scoots_1_month all_scoots_1_month if evertreated & year>=2018,a(city_id month_stat ) cluster(city_id)
eststo splag3: reghdfe first_launch nb_scoots_2_month all_scoots_2_month if evertreated & year>=2018,a(city_id month_stat ) cluster(city_id)
eststo splag4: reghdfe first_launch nb_scoots_1_month all_scoots_1_month if evertreated & year>=2018,a(city_id month_stat ) cluster(city_id)
estadd ysumm: splag? 

//table 11
eststo init_count: reghdfe new_launch  change_accidents_12m if evertreated & year>=2018,a(city_id month_stat) cluster(city_id)
eststo init_count2: reghdfe new_launch  change_accidents_12y if evertreated & year>=2018,a(city_id month_stat) cluster(city_id)
eststo init_dummy: reghdfe first_launch change_accidents_12m if evertreated & year>=2018,a(city_id month_stat) cluster(city_id)
eststo init_dummy2: reghdfe first_launch  change_accidents_12y if evertreated & year>=2018,a(city_id month_stat) cluster(city_id)
estadd ysumm: init_*





label define yl 9999 "never-treated" 2020 "treated 2020" 2021 "treated 2021", replace
label values year_intro yl
label var year_intro "launch"
label var month_stat "month"
label var nb_scoots_1_month "Launches in neighbor city (same month)"
label var nb_scoots_2_month "Launches in neighbor city (2 months)"
label var all_scoots_1_month "Launches in country (same month)"
label var all_scoots_2_month "Launches in country (2 months)"
		
esttab nevertreated_bad_choice?* ///
		using "$outfolder\tab11.tex", replace nonotes booktabs starlevels(* 0.1 ** 0.05 *** 0.01) ///
		lab transform(100*(exp(@)-1) 100*exp(@)) sub(\_ _)  ///
		drop(_cons) nomtitles ///
		stats(ymean N_clust N a sampleyears samplecities, label("Mean dep. var." "Cities" "Observations" Sample: "---year" "---city treated in ..") fmt(1 0 0 0 0 0) layout("@\%" @ @ @ @ @)) ///
		se(2) b(2) interaction(\(\times\)) 

		
esttab splag* ///
		using "$outfolder\tab9.tex", replace nonotes booktabs starlevels(* 0.1 ** 0.05 *** 0.01) ///
		lab sub(\_ _)  ///
		nodepv nomtitles mgroup("=1 if new firm launches" "=1 if first firm launches" , lhs(Dependent variable:) pattern(1 0 1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(})  erepeat(\cmidrule(lr){@span}) span) ///
		drop(_cons) order(nb_*) ///
		stats(ymean N_clust N , label("Mean dep. var." "Cities" "Observations") fmt(1 0 0) layout("@\%" @ @)) ///
		se(1) b(1) 
			
			
