/*******************************************************
* input:	monthly city panel
* output:	figures and tables in $outfolder
* date:		1. September 2023
* authors:	Cannon Cloud, Johannes Kasinger, Simon Heß
*******************************************************/




clear all
global outfolder "output"
set varabbrev off
set graphics off

use "data\monthly-panel.dta"

//collapse into city-level data 
collapse (mean) month_intro*, by(city country  sh_bikable   		carsper100 		 cmode_imp	   logincome population evertreated)
keep if evertreated
label var month_intro "\shortstack{Month of\\introduction}"

//standardize vars
foreach var of varlist  cmode_imp carsper100 sh_bikable logincome {
	sum `var'
	replace `var' = (`var' - r(mean))/r(sd)
}
replace population = population/100000
label var population "Population (in 100k)"
label var cmode_imp "Cycling modal share"
label var carsper100 "Cars per capita" 
label var sh_bikable "Share of bike lanes"
label var logincome	"log(GDP per capita)"
eststo predla1: reghdfe month_intro population sh_bikable , a(country)  cluster(city)
eststo predla2: reghdfe month_intro carsper100 population, a(country)  cluster(city)
eststo predla3: reghdfe month_intro cmode_imp population, a(country)  cluster(city)
eststo predla4ref2: reghdfe month_intro population logincome, a(country)  cluster(city)
eststo predla5ref2: reghdfe month_intro cmode_imp carsper100 sh_bikable  population logincome, a(country) cluster(city)

esttab predla1 predla2 predla3 predla4ref2 predla5ref2  ///
		using "$outfolder\tab8.tex", replace nonotes booktabs se starlevels(* 0.1 ** 0.05 *** 0.01) ///
		lab ///
		stats(N r2 , label("Cities" "\(R^2\)") fmt(0 2)) drop(_cons) ///
		se(3) b(3) 
		
/*** MAKE PLOT *****/
gen end = 743
gen oneyear = min(month_intro+12,end)
gen a = -strlen(city)
sort country month_intro month_intro2 month_intro3 a
gen order = -_n

by country: gen clab = country if _n==1


gen position = min(month_intro,end)

forval i=1/16 {
	gen position`i' = month_intro`i'
	gen l`i' = `i'
}
 tw (rbar month_intro oneyear order if country=="Austria", hor barw(0.8) col(maroon*1)) ///
	(rbar oneyear end order 		if country=="Austria", hor barw(0.8) col(maroon*0.8)) ///
	(rbar month_intro oneyear order if country=="Finland", hor barw(0.8) col(navy*1)) ///
	(rbar oneyear end order 		if country=="Finland", hor barw(0.8) col(navy*0.8)) ///
	(rbar month_intro oneyear order if country=="Germany", hor barw(0.8) col(forest_green*1)) ///
	(rbar oneyear end order 		if country=="Germany", hor barw(0.8) col(forest_green*0.8)) ///
	(rbar month_intro oneyear order if country=="Norway", hor barw(0.8) col(maroon*1)) ///
	(rbar oneyear end order			if country=="Norway", hor barw(0.8) col(maroon*0.8)) ///
	(rbar month_intro oneyear order if country=="Sweden", hor barw(0.8) col(navy*1)) ///
	(rbar oneyear end order 		if country=="Sweden", hor barw(0.8) col(navy*0.8)) ///
	(rbar month_intro oneyear order if country=="Switzerland", hor barw(0.8) col(forest_green*1)) ///
	(rbar oneyear end order 		if country=="Switzerland", hor barw(0.8) col(forest_green*0.8)) ///
	(scatter order position1, mcol(black)  msize(small) mlabcolor(white) ml(l1) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position2, mcol(black)  msize(small) mlabcolor(white) ml(l2) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position3, mcol(black)  msize(small) mlabcolor(white) ml(l3) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position4, mcol(black)  msize(small) mlabcolor(white) ml(l4) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position5, mcol(black)  msize(small) mlabcolor(white) ml(l5) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position6, mcol(black)  msize(small) mlabcolor(white) ml(l7) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position7, mcol(black)  msize(small) mlabcolor(white) ml(l8) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position8, mcol(black)  msize(small) mlabcolor(white) ml(l9) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position9, mcol(black)  msize(small) mlabcolor(white) ml(l10) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position10, mcol(black)  msize(small) mlabcolor(white) ml(l11) mlabsize(tiny)  mlabposition(0)) ///
	(scatter order position11, mcol(black)  msize(small) mlabcolor(white) ml(l12) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position12, mcol(black)  msize(small) mlabcolor(white) ml(l13) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position13, mcol(black)  msize(small) mlabcolor(white) ml(l14) mlabsize(tiny)  mlabposition(0)) ///
	(scatter order position14, mcol(black)  msize(small) mlabcolor(white) ml(l15) mlabsize(tiny) mlabposition(0)) ///
	(scatter order position15, mcol(black)  msize(small) mlabcolor(white) ml(l16) mlabsize(tiny) mlabposition(0)) ///
	(scatter order end, mcol(black)  msize(vtiny) mlabcolor(black) ml(clab) ) ///
	(scatter order position , msymb(none) ml(city) mlabposition(9) mlabsize(vsmall) mlabcolor(black)) ///
	(scatteri 0 `=737+0.5' -93 `=737+0.5', recast(line) lcolor(black) legend(off) ) ///
	, xscale(range(700 750)) legend(off)  graphregion(color(white))  ytit("") yla(none) ysize(15) xsize(12) scale(0.7) name(dates,replace) ///
	text( 2  737 "End of accident data", size(small))

graph export  "$outfolder\fig3.pdf", as(pdf) replace
set graphics on
