/*******************************************************
* input:	monthly city panel
* output:	figures and tables in $outfolder
* date:		1. September 2023
* authors:	Cannon Cloud, Johannes Kasinger, Simon Heß
*******************************************************/




clear all
global outfolder "output"
set varabbrev off
set graphics off

use "data\monthly-panel.dta"

reghdfe Y treated if evertreated==1,a(city_id month_stat) cluster(city_id)

eststo twfe
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd ysumm
			
reghdfe Y treated if evertreated==1,a(city_id month_stat year#country_id) cluster(city_id)
eststo twfe_cfx
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd ysumm
			
ppmlhdfe accidents_month_all treated if evertreated==1,a(city_id month_stat) cluster(city_id)
eststo poisson
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd ysumm

ppmlhdfe accidents_month_all treated if evertreated==1,a(city_id month_stat year#country_id) cluster(city_id)
eststo poisson_fx
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd ysumm
		
			
reghdfe Y number_scooter_companies  if evertreated==1,a(city_id month_stat) cluster(city_id)
eststo twfe_int
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd ysumm
reghdfe Y number_scooter_companies  if evertreated==1,a(city_id month_stat year#country_id) cluster(city_id)
eststo twfe_int_cfx
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd ysumm

			


ivreghdfe Y (treated   = c.bin_scoots_other_cities#c.(sh_bikable_decmeaned carsper100_decmeaned cmode_imp_decmeaned  PPS_pc_decmeaned population) ) if evertreated==1,a(city_id month_stat) cluster(city_id) first
eststo twsls_binary
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd ysumm
		
			
			
ivreghdfe Y (treated   = c.bin_scoots_other_cities#c.(sh_bikable_decmeaned carsper100_decmeaned cmode_imp_decmeaned  PPS_pc_decmeaned population) ) if evertreated==1,a(city_id month_stat year#country_id) cluster(city_id) first
eststo twsls_binary_fx
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd ysumm
 
/* main estimate for comparison */
 
did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
     wtr(wtr_full) ///
	leaveout avgeffectsby(cohorts_quarters)
eststo borusyak


 
did_imputation Y city_id month_stat month_intro  if evertreated==1,  ///
    wtr(wtr_full) leaveout avgeffectsby(cohorts_quarters) fe(month_stat city_id year#country_id) autosample

eststo borusyakfx
			unique city_id if e(sample) & treated
			estadd scalar treated_cities=r(sum) 
			unique city_id if e(sample) 
			estadd scalar N_clust=r(sum)
			estadd ysumm

 
 
gen treat_full = .
label var treat_full "Effect of introduction (\%)"
label var number_scooter_companies "Effect of one additional company (\%)"
	
estfe borusyakfx twfe_cfx twsls_binary_fx twfe_int_cfx poisson_fx twfe twsls_binary twfe_int  poisson, labels(year#country_id "month-country FE")
	
esttab  borusyak borusyakfx twfe  twfe_cfx twsls_binary twsls_binary_fx poisson poisson_fx ///
		using "$outfolder\tab5.tex", replace nonotes booktabs  starlevels(* 0.1 ** 0.05 *** 0.01) ///
		rename(tau treat_full treated treat_full tau_wtr_full treat_full) ///
		lab transform(100*(exp(@)-1) 100*exp(@)) ///
		indicate("Country-year FEs=0.year#0.country_id c1" ,		label("\(\checkmark\)" "~")) ///
		mtitle("Imputation" "Imputation" "OLS" "OLS" "IV" "IV" "\shortstack{Poisson\\(PPML)}" "\shortstack{Poisson\\(PPML)}") ///
		mgroup("\shortstack{Event-study estimate\\(Borusyak et al. 2023)}" ///
		"\shortstack{Two-way fixed effects\\(TWFE)}" , pattern(1 0 1 0 0 0  0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(})  erepeat(\cmidrule(lr){@span}) span) ///
		stats(rkf treated_cities N_clust N , label("Kleibergen-Paap Wald rk \rlap{\(F\)-stat}" "\midrule %Treated cities" "Cities" "Observations") fmt(1 0 0 0 0)) ///
		drop("_cons" 0.month_stat 0.city_id)   b(1) se(1)
		

		
		
esttab  twfe_int twfe_int_cfx ///
		using "$outfolder\tab6.tex", replace nonotes booktabs  starlevels(* 0.1 ** 0.05 *** 0.01) ///
		rename(tau treat_full treated treat_full tau_wtr_full treat_full) ///
		lab transform(100*(exp(@)-1) 100*exp(@)) ///
		indicate("Country-year FEs=0.year#0.country_id " ,		label("\(\checkmark\)" "~")) ///
		mtitle("OLS" "OLS" "IV" "IV") ///
		stats( treated_cities N_clust N , label("%Treated cities" "Cities" "Observations") fmt(1 0 0 0 0)) ///
		drop("_cons" 0.month_stat 0.city_id)   b(1) se(1)
		
