library(haven) 
library(dplyr)
devtools::install_github("synth-inference/synthdid")
library(synthdid)
library(abind)


multi_sdid <-function(data){
  
  
  untreated=0
  data$initial_treat_var=ifelse(data$initial_treat_var==untreated, 0, data$initial_treat_var)
  
  treated_periods <- sort(unique(data$initial_treat_var[which(data$initial_treat_var > 0)]))
  treated_periods <- treated_periods[which(treated_periods > min(data$time_var) + 1)]
  
  result_matrix <- matrix(ncol = 7, nrow = length(treated_periods))
  tau_hat_list <- list()
  
  
  for (i in 1:length(treated_periods)) {
    subbed <- data[which(data$initial_treat_var == treated_periods[i] | data$initial_treat_var > last_period | data$initial_treat_var == untreated), ]
    month_of_cohort <- unique(filter(subbed, treated_periods[i] == initial_treat_var)$monthofintro)
    subbed <- mutate(subbed, current_treat = ifelse(initial_treat_var <= last_period & initial_treat_var != 0, 1, 0)) 
    
    if (nrow(filter(subbed, initial_treat_var == treated_periods[i] )) != 0) {
      
      subbed[, ncol(subbed) + 1] <- 0
      colnames(subbed)[ncol(subbed)] <- "post_treat"
      
      subbed$post_treat = ifelse(subbed$time_var >= subbed$initial_treat_var & subbed$initial_treat_var != 0, 1, 0)
      
      panel = subbed
      unit = "unit"
      time = "time_var"
      outcome = "outcome_var"
      treatment = "post_treat"
      ever_treated = "ever_treated"
      current_treat = "current_treat"
      city = "city"
      
      keep = c(unit, time, outcome, treatment, ever_treated, current_treat, city)
      if (!all(keep %in% 1:ncol(panel) | keep %in% colnames(panel))) {
        stop("Column identifiers should be either integer or column names in `panel`.")
      }
      index.to.name = function(x) {
        if (x %in% 1:ncol(panel)) {
          colnames(panel)[x]
        }
        else {
          x
        }
      }
      unit = index.to.name(unit)
      time = index.to.name(time)
      outcome = index.to.name(outcome)
      treatment = index.to.name(treatment)
      keep = c(unit, time, outcome, treatment, ever_treated, current_treat, city)
      panel = panel[keep]
      if (!is.data.frame(panel)) {
        stop("Unsupported input type `panel.`")
      }
      if (anyNA(panel)) {
        stop("Missing values in `panel`.")
      }
      if (length(unique(panel$post_treat)) == 1) {
        stop("There is no variation in treatment status.")
      }
      if (!all(panel$post_treat %in% c(0, 1))) {
        stop("The treatment status should be in 0 or 1.")
      }
      panel = data.frame(lapply(panel, function(col) {
        if (is.factor(col) || inherits(col, "Date"))
          as.character(col)
        else col
      }), stringsAsFactors = FALSE)
      val <- as.vector(table(panel$unit, panel$time_var))
      if (!all(val == 1)) {
        stop("Input `panel` must be a balanced panel: it must have an observation for every unit at every time.")
      }
      panel = panel[order(panel[, current_treat], panel[, unit], panel[, time]), ]
      num.years = length(unique(panel[, time]))
      num.units = length(unique(panel[, unit]))
      Y = matrix(panel[, outcome], num.units, num.years, byrow = TRUE,
                 dimnames = list(unique(panel[, unit]), unique(panel[,
                                                                     time])))
      W = matrix(panel[, treatment], num.units, num.years, byrow = TRUE,
                 dimnames = list(unique(panel[, unit]), unique(panel[,
                                                                     time])))
      w = apply(W, 1, any)
      T0 = unname(which(apply(W, 2, any))[1] - 1)
      N0 = sum(!w)
      if (!(all(W[!w, ] == 0) && all(W[, 1:T0] == 0) && all(W[w,
                                                              (T0 + 1):ncol(Y)] == 1))) {
        stop("The package cannot use this data. Treatment adoption is not simultaneous.")
      }
      
      tau_hat <- synthdid_estimate(Y, N0, T0)
      tau_hat_list[[i]] <- tau_hat
      
      result_matrix[i, 1] <- treated_periods[i]
      result_matrix[i, 2] <- as.numeric(tau_hat)
      result_matrix[i, 3] <- sqrt(vcov(tau_hat, method = "placebo", replications = 250))
      result_matrix[i, 4] <- as.numeric(result_matrix[i, 2]) - (1.96 * as.numeric(result_matrix[i, 3]))
      result_matrix[i, 5] <- as.numeric(result_matrix[i, 2]) + (1.96 * as.numeric(result_matrix[i, 3]))
      result_matrix[i, 6] <- nrow(subbed[which(subbed$post_treat == 1), ])
      result_matrix[i, 7] <- sum((group_by(subbed, unit) |> summarise(current_treat = first(current_treat)))$current_treat)
    }
  }
  
  result_matrix <- as.data.frame(result_matrix)
  colnames(result_matrix) <- c("treatment_period", "tau_hat", "standard_error", "lower_95_CI", "upper_95_CI", "post_treat_months", "current_treat")
  
  result_matrix <- filter(result_matrix, !is.na(treatment_period))
  result_matrix$weight <- as.numeric(result_matrix[, 6]) / sum(as.numeric(result_matrix[, 6]))
  result_matrix <- mutate(result_matrix, cum_treat = cumsum(current_treat))
  
  
  overall_estimator <- sum(result_matrix$weight * as.numeric(result_matrix[, 2]), na.rm = T)
  overall_se=sqrt(sum((result_matrix$weight^2)*as.numeric(result_matrix[,3])^2, na.rm = T))
  overall_p=2*pt(q=sqrt(((overall_estimator/overall_se)^2)), df=(nrow(data)-length(unique(data$time_var))-length(unique(data$unit))), lower.tail=FALSE)
  
  tau_hat_list_plot <- lapply(tau_hat_list, plot)
  
  #add sum of weights to plot
  MSPE <- data.frame()
  
  #add Mean squared prediction error
  for (z in 1:length(tau_hat_list_plot)) {
    foo <- filter(tau_hat_list_plot[[z]][["layers"]][[1]][["data"]], x < result_matrix$treatment_period[z]) |>
      group_by(color) |>
      mutate(y = y - mean(y)) |>
      ungroup() |>
      group_by(x) |>
      summarise(y = diff(y, lag = 1)) |>
      ungroup() |>
      summarise(MSPE = sum(y^2),
                month_num = n())
    MSPE <- rbind(MSPE, foo)
  }
  
  MSPE <- mutate(MSPE, MSPE = MSPE/month_num)
  weighted.mean(x = MSPE$MSPE, w = MSPE$month_num)
  
  results <- matrix(ncol = 8, nrow = 1)
  colnames(results) <- c("ATT", "SE", "P", "MSPE", "treated_cities", "all_cities", "months", "post_treat_obs")
  t = 1
  
  results[t,1] <- paste0(overall_estimator, ifelse(overall_p < .05 & overall_p > .01,"**",
                                                   ifelse(overall_p < .1 & overall_p > .05,"*",
                                                          ifelse(overall_p < .01,"***",""))))
  results[t,2] <- paste0(overall_se)
  results[t,3] <- paste0(overall_p)
  results[t,4] <- weighted.mean(x = MSPE$MSPE, w = MSPE$month_num)
  results[t,5] <- sum(result_matrix$current_treat)
  results[t,6] <- sum(result_matrix$current_treat) + length(unique(filter(data, ever_treated == 0)$city))
  results[t,7] <- length(unique(data$time_var))
  results[t,8] <- sum(data$treatment_var)
  
  return(results)
}

#prep_data for main spec

acc_data <- read_dta("data/monthly-panel.dta")

last_period = 731 #740 #731 #725
first_period = 672 #672 #696

main_spec <- mutate(acc_data, scooter_dummy = ifelse(is.na(treated), 0, treated),
                   month_intro = ifelse(is.na(month_intro), 0, month_intro),
                   outcome_var = accidents_month_all) |>
  group_by(city_id) |>
  mutate(last_date = max(month_stat),
         first_date = min(month_stat),
         monthofintro = ifelse(month_intro == month_stat, month, "00"),
         monthofintro = max(as.numeric(monthofintro)),
         month_intro = max(month_intro),
         month_intro = ifelse(month_intro > last_period, 0, month_intro)) |>
  ungroup() |>
  filter(!is.na(month_stat),
         last_date >= last_period,
         month_stat <= last_period,
         first_date <= first_period,
         month_stat >= first_period)

main_spec = select(main_spec, month_intro, outcome_var, city_id, scooter_dummy, month_stat, year, month, first_date, last_date, monthofintro, city, country, population) |>
  rename(initial_treat_var = month_intro,
         unit = city_id,
         treatment_var = scooter_dummy,
         time_var = month_stat) |>
  mutate(initial_treat_var = as.integer(initial_treat_var),
         unit = as.integer(unit),
         time_var = as.integer(time_var),
         outcome_var = ifelse(outcome_var== 0, 1, outcome_var),
         outcome_var = as.numeric(log(outcome_var))) |>
  group_by(unit) |>
  mutate(ever_treated = max(treatment_var, na.rm = T)) 

results_main <- multi_sdid(main_spec)

#prep_data for with sweden

last_period = 731 #740 #731 #725
first_period = 696 #672 #696

with_sweden <- mutate(acc_data, scooter_dummy = ifelse(is.na(treated), 0, treated),
                    month_intro = ifelse(is.na(month_intro), 0, month_intro),
                    outcome_var = accidents_month_all) |>
  group_by(city_id) |>
  mutate(last_date = max(month_stat),
         first_date = min(month_stat),
         monthofintro = ifelse(month_intro == month_stat, month, "00"),
         monthofintro = max(as.numeric(monthofintro)),
         month_intro = max(month_intro),
         month_intro = ifelse(month_intro > last_period, 0, month_intro)) |>
  ungroup() |>
  filter(!is.na(month_stat),
         last_date >= last_period,
         month_stat <= last_period,
         first_date <= first_period,
         month_stat >= first_period)

with_sweden = select(with_sweden, month_intro, outcome_var, city_id, scooter_dummy, month_stat, year, month, first_date, last_date, monthofintro, city, country, month, population, year) |>
  rename(initial_treat_var = month_intro,
         unit = city_id,
         treatment_var = scooter_dummy,
         time_var = month_stat) |>
  mutate(initial_treat_var = as.integer(initial_treat_var),
         unit = as.integer(unit),
         time_var = as.integer(time_var),
         outcome_var = ifelse(outcome_var== 0, 1, outcome_var),
         outcome_var = as.numeric(log(outcome_var))) |>
  group_by(unit) |>
  mutate(ever_treated = max(treatment_var, na.rm = T)) 

results_swede <- multi_sdid(with_sweden)

#no winter

last_period = 731 #740 #731 #725
first_period = 672 #672 #696

no_wint <- mutate(acc_data, scooter_dummy = ifelse(is.na(treated), 0, treated),
                    month_intro = ifelse(is.na(month_intro), 0, month_intro),
                    outcome_var = accidents_month_all) |>
  group_by(city_id) |>
  mutate(last_date = max(month_stat),
         first_date = min(month_stat),
         monthofintro = ifelse(month_intro == month_stat, month, "00"),
         monthofintro = max(as.numeric(monthofintro)),
         month_intro = ifelse(month == "01" & month_intro != 0 & month_intro == month_stat, month_intro + 2, #shift for eliminating 4 winter months
                                      ifelse(month == "02" & month_intro != 0 & month_intro == month_stat, month_intro + 1,
                                             ifelse(month == "11" & month_intro != 0 & month_intro == month_stat, month_intro + 4,
                                                    ifelse(month == "12" & month_intro != 0 & month_intro == month_stat, month_intro + 3, month_intro)))),
         month_intro = max(month_intro),
         month_intro = ifelse(month_intro > last_period, 0, month_intro)) |>
  ungroup() |>
  filter(!(month %in% c("11", "12", "01", "02")), #exclude nov-feb
         !is.na(month_stat),
         last_date >= last_period,
         month_stat <= last_period,
         first_date <= first_period,
         month_stat >= first_period)

no_wint = select(no_wint, month_intro, outcome_var, city_id, scooter_dummy, month_stat, year, month, first_date, last_date, monthofintro, city, country, month, population, year) |>
  rename(initial_treat_var = month_intro,
         unit = city_id,
         treatment_var = scooter_dummy,
         time_var = month_stat) |>
  mutate(initial_treat_var = as.integer(initial_treat_var),
         unit = as.integer(unit),
         time_var = as.integer(time_var),
         outcome_var = ifelse(outcome_var== 0, 1, outcome_var),
         outcome_var = as.numeric(log(outcome_var))) |>
  group_by(unit) |>
  mutate(ever_treated = max(treatment_var, na.rm = T)) 

results_nowint <- multi_sdid(no_wint)

final_results <-rbind(results_main, results_swede, results_nowint)

rownames(final_results) <- c("Jan2016dec2020", "withSweden", "J2016d2020nowint") 

